import '@/assets/base.css'
import '@mdi/font/css/materialdesignicons.css'


import { createApp } from 'vue'
import { createPinia } from 'pinia'

// @ts-ignore
import App from './App.vue'
import router from './router'

// Vuetify
import 'vuetify/styles'
import createVuetify from '@/plugins/vuetify'
import { onAuthStateChanged } from 'firebase/auth'
import { auth } from '@/stores/utils/firebase'
import { useUserStore } from '@/stores/userStore'
import { useChatStore } from '@/stores/chatStore'


const vuetify = createVuetify

const app = createApp(App)
app.use(vuetify)
app.use(createPinia())
app.use(router)

app.mount('#app')

const userStore = useUserStore()
const chatStore = useChatStore()
/**
 * This function is used whenever the app is open.
 * It checks the status of the suer and the path entered and automatically redirect the user
 * on the right route.
 */
onAuthStateChanged(auth, async (user) => {
  console.log("State has been changed !")
  if (user) {
    // User is signed in, see docs for a list of available properties
    // https://firebase.google.com/docs/reference/js/auth.user
    const uid = user.uid
    userStore.setUser(user)
    userStore.setUid(uid)
    userStore.setIsLoggedIn(true)
    userStore.loadUser()
    chatStore.getAllPrivateChatRoom()
    console.log(router.currentRoute.value.fullPath)
    if (!router.currentRoute.value.fullPath.startsWith("/chart"))
      await router.push({ name: 'Home' })
  } else {
    console.log("User is not logged in")
    userStore.setIsLoggedIn(false)
    if (router.currentRoute.value.fullPath.startsWith("/chart"))
      await router.push({ name: 'Chart' })
    else {
      await router.push({ name: 'Login' })
    }
  }
})
