/**
 * Class representing a tile in the game map.
 */
export class Case {
  /**
   * Property indicating whether the tile is an obstacle or not.
   * @type {boolean}
   */
  public isObstacle = false;

  /**
   * Create a new tile.
   * @param {boolean} isObstacle - Indicates whether the tile is an obstacle or not.
   */
  constructor(isObstacle: boolean) {
    this.isObstacle = isObstacle
  }
}

/**
 * Function to generate a 2D array representing the game map from a text source.
 * Each character in the text source is converted to a tile, with '0' indicating a non-obstacle tile.
 * @param {string} txt_src - The URL of the text source.
 * @return {Array<Array<Case>>} The 2D array representing the game map.
 */
export function getTileMapCollisionFromTxt(txt_src: string): Array<Array<Case>> {
  const mapObstacle : Array<Array<Case>> = [[]]
  fetch(txt_src).then((res) => res.text()).then((text) => {
    let index = 0;
    for (const c of text){
      if( c === '\n' ){
        index++
        mapObstacle.push([])
      } else {
        mapObstacle[index].push(new Case(c !== '0'))
      }
    }
  })
  return mapObstacle
}
