'use strict';

import {defineStore} from "pinia";

const SUCCESS_MESSAGE_TIMEOUT = 5000;
const ERROR_MESSAGE_TIMEOUT = -1; // Never hide error messages
const MAXIMUM_DISPLAYED_NOTIFICATIONS = 5;

export const useNotificationStore = defineStore('notification', {
    state: () => ({
      notifications: [],
    }),
    actions: {
      /**
       * Adds a success message to the notification store.
       *
       * @param successMessage {string} - Success message
       */
      setSuccessMessage(successMessage) {
        this.setMessages(successMessage, 'mdi-check-circle-outline', 'primary_container','on_primary_container', SUCCESS_MESSAGE_TIMEOUT)
      },
      /**
       * Adds an error message to the notification store.
       *
       * @param errorMessage {string} - Error message
       */
      setErrorMessage(errorMessage) {
        this.setMessages(errorMessage, 'mdi-alert-circle-outline', 'error_container', 'on_error_container', ERROR_MESSAGE_TIMEOUT)
      },
      /**
       * Adds a message to the notification store.
       *
       * @param message {string} - Message
       * @param icon {string} - Icon of the message
       * @param container{string}
       * @param color {string} - Color of the message
       * @param timeout {number} - Timeout in milliseconds
       */
      setMessages(message, icon,container,  color, timeout) {
        this.notifications.push({
          show: true,
          color: color,
          container: container,
          icon: icon,
          message: message,
          timeout: timeout,
        });
      }
      ,
      /**
       * Removes a message from the notification store.
       *
       * @param index {number} - Index of the message to remove
       */
      popNotification(index) {
        this.notifications.splice(index, 1);
      }
      ,
      /**
       * Removes all messages from the notification store.
       */
      clearNotifications() {
        this.notifications = [];
      }
    },
    getters: {
      /**
       * Returns the snackbars to display.
       *
       * @returns {Array} - Snackbars to display
       */
      getNotifications() {
        this.notifications = this.notifications.filter((notification) => notification.show);
        return this.notifications.filter((notification, index) => {
          return index < MAXIMUM_DISPLAYED_NOTIFICATIONS;
        });
      }
    }
    ,
  })
;
