import { defineStore } from 'pinia'

/**
 * Defines a store named 'uiStore' using the 'defineStore' function from 'pinia'.
 * This store is used to manage the state and actions related to the user interface.
 */
export const useUiStore = defineStore('uiStore', {
    /**
     * Defines the initial state of the store.
     */
    state: () => {
        return {
            heroProfileIsOpen: false as boolean, // A flag indicating whether the hero profile is open.
            playerProfileIsOpen: false as boolean, // A flag indicating whether the player profile is open.
            chatDialogIsOpen: false as boolean, // A flag indicating whether the chat dialog is open.
            settingsDialogIsOpen: false as boolean, // A flag indicating whether the settings dialog is open.
            disconnectIsOpen: false as boolean, // A flag indicating whether the disconnect dialog is open.
            bookSignIsOpen: false as boolean, // A flag indicating whether the book sign is open.
            libraryIsOpen: false as boolean // A flag indicating whether the library is open.
        }
    },
    actions: {
        /**
         * Opens the player profile.
         */
        openPlayerProfile() {
            this.playerProfileIsOpen = true
            console.log("Player Profile is open: ", this.playerProfileIsOpen)
        },
        /**
         * Closes the player profile.
         */
        closePlayerProfile() {
            this.playerProfileIsOpen = false
            console.log("Player Profile is open: ", this.playerProfileIsOpen)
        },
        /**
         * Toggles the hero profile.
         */
        toggleHeroProfile() {
            this.heroProfileIsOpen = !this.heroProfileIsOpen
            console.log("Player Profile is open: ", this.heroProfileIsOpen)
        },
        /**
         * Toggles the chat dialog.
         */
        toggleChatDialog() {
            this.chatDialogIsOpen = !this.chatDialogIsOpen
            console.log("Chat dialog is open: ", this.chatDialogIsOpen)
        },
        /**
         * Toggles the settings dialog.
         */
        toggleSettingsDialog() {
            this.settingsDialogIsOpen = !this.settingsDialogIsOpen
            console.log("Settings dialog is open: ", this.settingsDialogIsOpen)
        },
        /**
         * Toggles the disconnect dialog.
         */
        toggleDisconnectDialog() {
            this.disconnectIsOpen = !this.disconnectIsOpen
            console.log("Disconnect dialog is open: ", this.disconnectIsOpen)
        },
        /**
         * Toggles the book sign.
         */
        toggleBookSign() {
            this.bookSignIsOpen = !this.bookSignIsOpen
            console.log("Book sign is open: ", this.bookSignIsOpen)
        },
        /**
         * Toggles the library ui
         */
         toggleLibrary() {
           this.libraryIsOpen = !this.libraryIsOpen
              console.log("Library is open: ", this.libraryIsOpen)
         }

    },
})