const {Server} = require("socket.io")
const express = require('express');
const {createServer} = require('node:http');
const pnj = require('./pnj.js');

const app = express();
const server = createServer(app);
const io = new Server(server, {cors: {origin: '*'}});

app.get('/', () => {
});


let players = [
    new pnj('npc_100906', 750, 280),
    new pnj('npc_150561', 70, 300),
    new pnj('npc_152036', 450, 540),
]

// Setting up socket.io connection events
io.on('connection', (socket) => {
    /**
     * Event for a new player
     * Adds the new player to the players array and emits a "new player" event
     */
    socket.on("new player", (msg) => {
        players.push({uid: msg.uid, x: msg.x, y: msg.y})
        console.log("New player join the game ! 😶‍🌫️" + msg.uid)
        io.emit("new player", {uid: msg.uid, players: players})
    })

    /**
     * Event for a player moving
     * Updates the player's position in the players array and emits a "player moving" event
     */
    socket.on('player moving', (msg) => {
        let index = players.findIndex((item) => item.uid === msg.uid)
        players[index] = {uid: msg.uid, x: msg.x, y: msg.y}
        io.emit("player moving", {uid: msg.uid, direction: {x: msg.x, y: msg.y, type: msg.direction}})
    });

    /**
     * Event for a player disconnecting
     * Removes the player from the players array and emits a "player disconnected" event
     */
    socket.on("close connection", (msg) => {
        console.log("Player has quit the game 🏃‍♂️")
        let index = players.findIndex((item) => item.uid === msg.uid)
        if (index > -1) {
            players.splice(index, 1)
        }
        io.emit('player disconnected', msg)
    })

    /**
     * Event for a chat message
     * Emits a chat message event to the specified chatroom
     */
    socket.on('chat message', (msg) => {
        io.emit(`${msg.chatroom}`, msg)
    });

});

// Starting the server on the specified port
const port = parseInt(process.env.PORT) || 8080;
server.listen(port, () => {
    console.log('server running at http://localhost:3000');
});

